@@ -3,7 +3,7 @@ package GeoIP2::Model::Insights;
 use strict;
 use warnings;
 
-our $VERSION = '2.005000';
+our $VERSION = '2.005001';
 
 use Moo;
 
@@ -33,7 +33,7 @@ GeoIP2::Model::Insights - Model class for GeoIP2 Precision: Insights
 
 =head1 VERSION
 
-version 2.005000
+version 2.005001
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ version 2.005000
   use GeoIP2::WebService::Client;
 
   my $client = GeoIP2::WebService::Client->new(
-      user_id     => 42,
+      account_id  => 42,
       license_key => 'abcdef123456',
   );
 
